<?php

namespace Detektivo\Controller;


class Detektivo extends Controller {

    public function index() {

        $types = $this->module('detektivo')->indexTypes();

        return $this->render('detektivo:views/index.php', compact('types'));
    }

    public function create() {

        if ($index = $this->param('index', false)) {

            $this->hasValidCsrfToken(true);

            if ($this->module('detektivo')->exists($index['name'])) {
                $this->stop(['error' => "Index - {$index['name']} - already exists!"], 400);
            }

            $idx = $this->module('detektivo')->createIndex($index['name'], $index);

            $this->helper('eventStream')->add('detektivo.indexes.updated', ['action' => 'create', 'name' => $index['name']]);

            return $idx;
        }

        $types = $this->module('detektivo')->indexTypes();

        return $this->render('detektivo:views/create.php', compact('types'));
    }

    public function remove($name = null, $id = null) {

        $this->hasValidCsrfToken(true);

        if (!$name || !$this->module('detektivo')->exists($name)) {
            return false;
        }

        $this->module('detektivo')->removeIndex($name);

        $this->helper('eventStream')->add('detektivo.indexes.updated', ['action' => 'remove', 'name' => $name]);

        return ['success' => true];
    }

    public function load() {

        $this->hasValidCsrfToken(true);

        $indexes = $this->module('detektivo')->indexes();

        if (!$this->helper('acl')->isSuperAdmin()) {

            $acl = $this->helper('acl');

            $indexes = array_filter($indexes, function($index) use($acl) {

                if ($acl->isAllowed('content/indexes/manage')) {
                    return true;
                }

                return $acl->isAllowed("content/{$index['name']}/read");
            });
        }

        return array_values($indexes);
    }

    public function search($name = null) {

        $this->hasValidCsrfToken(true);

        if (!$name || !$this->module('detektivo')->exists($name)) {
            return false;
        }

        $query = $this->param('q:string', '');
        $limit = $this->param('limit:int', 20);
        $offset = $this->param('offset:int', 0);

        $idx = $this->module('detektivo')->index($name);

        $result = $idx->search($query, [
            'limit' => $limit,
            'offset' => $offset,
        ]);

        $pages = ceil($result['estimatedTotalHits'] ?? 0 / $limit);
        $page  = 1;

        if ($pages > 1 && $offset) {
            $page = ceil($offset / $limit) + 1;
        }

        $result['pages'] = $pages;
        $result['page'] = $page;
        $result['total'] = $idx->countDocuments();

        return $result;
    }

}
