<?php

namespace Layout\Helper;

class Components extends \Lime\Helper {

    protected array $components = [];

    protected function initialize() {

        $this->components = $this->app['debug'] ? $this->cache(false) : $this->app->memory->get('layout.components', function() {
            return $this->cache();
        });
    }

    public function components(): array {
        return $this->components;
    }

    public function cache(bool $persistent = true): array {

        $cache = [

            'grid' => [

                'label' => 'Grid',
                'group' => 'Layout',
                'fields' => [
                    ['name' => 'class', 'type' => 'text'],
                    [
                        'name' => 'colWidth',
                        'type' => 'select',
                        'opts' => [
                            'options' => ['auto', 1, 2, 3, 4],
                        ],
                    ],
                ],
                'preview' => null,
                'children' => false,
            ],

            'row' => [

                'label' => 'Row',
                'group' => 'Layout',
                'fields' => [
                    ['name' => 'class', 'type' => 'text'],
                ],
                'preview' => null,
                'children' => false,
            ],

            'button' => [
                'label' => 'Button',
                'group' => 'Basic',
                'fields' => [
                    ['name' => 'url', 'type' => 'text'],
                    ['name' => 'caption', 'type' => 'text'],
                    ['name' => 'target', 'type' => 'select', 'opts' => ['options' => ['_self', '_blank'], 'default' => '_self']],
                ],
                'preview' => null,
                'children' => false
            ],

            'divider' => [
                'label' => 'Divider',
                'group' => 'Basic',
                'fields' => [

                ],
                'preview' => null,
                'children' => false
            ],

            'heading' => [
                'label' => 'Heading',
                'group' => 'Text',
                'fields' => [
                    ['name' => 'text', 'type' => 'text'],
                    ['name' => 'level', 'type' => 'select', 'opts' => ['options' => [1,2,3,4,5,6]]],
                ],
                'preview' => '<div class="kiss-padding-small kiss-color-muted kiss-flex kiss-flex-middle" v-if="data.text"><strong class="kiss-margin-xsmall-right" v-if="data.level">H{{data.level}}</strong> {{ data.text }}</div>',
                'children' => false,
                'opts' => [
                    'previewComponent' => null
                ]
            ],

            'html' => [
                'label' => 'HTML',
                'group' => 'Misc',
                'fields' => [
                    ['name' => 'html', 'type' => 'code', 'opts' => ['mode' => 'html']],
                ],
                'preview' => null,
                'children' => false
            ],

            'image' => [
                'label' => 'Image',
                'group' => 'Media',
                'fields' => [
                    ['name' => 'asset', 'type' => 'asset', 'opts' => ['filter' => ['type' => 'image']]],
                    ['name' => 'url', 'label' => 'Link url', 'type' => 'text', 'opts' => ['placeholder' => 'https://...']],
                ],
                'preview' => '<div class="kiss-bgcolor-transparentimage" v-if="data.asset"><img class="kiss-margin-auto" :src="App.route(`/assets/thumbnail/${data.asset._id}?m=bestFit&mime=auto&h=100&t=${data.asset._modified}`)"></div>',
                'children' => false
            ],

            'video' => [
                'label' => 'Video',
                'group' => 'Media',
                'fields' => [
                    ['name' => 'video', 'type' => 'asset', 'opts' => ['filter' => ['type' => 'video']]],
                    ['name' => 'poster', 'type' => 'asset', 'label' => 'Poster Image', 'opts' => ['filter' => ['type' => 'image']]],
                ],
                'preview' => null,
                'children' => false
            ],

            'markdown' => [
                'label' => 'Markdown',
                'group' => 'Text',
                'fields' => [
                    ['name' => 'markdown', 'type' => 'code', 'opts' => ['mode' => 'markdown']],
                ],
                'preview' => '<div class="kiss-padding-small kiss-color-muted" v-if="data.markdown">{{ truncate(data.markdown, 50) }}</div>',
                'children' => false,
                'opts' => [
                    'previewComponent' => null
                ]
            ],

            'link' => [
                'label' => 'Link',
                'group' => 'Basic',
                'fields' => [
                    ['name' => 'url', 'type' => 'text'],
                    ['name' => 'caption', 'type' => 'text'],
                    ['name' => 'target', 'type' => 'select', 'opts' => ['options' => ['_self', '_blank'], 'default' => '_self']],
                ],
                'preview' => null,
                'children' => false
            ],

            'richtext' => [
                'label' => 'Richtext',
                'group' => 'Text',
                'fields' => [
                    ['name' => 'html', 'type' => 'wysiwyg'],
                ],
                'preview' => '<div class="kiss-padding-small kiss-color-muted kiss-overflow-y-auto" style="max-height:250px" v-if="data.html" v-html="stripTags(data.html, \'<br><p><strong><i><div><em><hr><code><h1><h2><h3><h4><h5><h6>\')"></div>',
                'children' => false,
                'opts' => [
                    'previewComponent' => null
                ]
            ],

            'section' => [
                'label' => 'Section',
                'group' => 'Layout',
                'fields' => [
                    ['name' => 'class', 'type' => 'text']
                ],
                'preview' => null,
                'children' => true
            ],

            'spacer' => [
                'label' => 'Spacer',
                'group' => 'Layout',
                'fields' => [
                    ['name' => 'size', 'type' => 'text'],
                ],
                'preview' => '<div class="kiss-padding-small kiss-color-muted kiss-flex kiss-flex-middle" v-if="data.size"><icon class="kiss-margin-xsmall-right">unfold_more</icon>{{ data.size }}</div>',
                'children' => false,
                'opts' => [
                    'previewComponent' => null
                ]
            ]
        ];

        $components = $this->app->dataStorage->find('layout/components', [
            'sort' => ['name' => 1]
        ])->toArray();

        foreach ($components as $component) {
            $cache[$component['name']] = $component['meta'];
        }

        if ($persistent) {
            $this->app->memory->set('layout.components', $cache);
        }

        return $cache;
    }

    public function process($array, array $context = []) {

        if (!is_array($array)) {
            return $array;
        }

        foreach ($array as $k => $v) {

            if (is_array($array[$k])) {
                $array[$k] = $this->process($array[$k], $context);
            }

            if ($k == 'component' && \is_string($v) && isset($this->components[$v])) {
                $this->app->trigger('layout.component.process', [$v, &$array, $context, $this->components[$v]]);
            }
        }

        return $array;
    }
}
