export default {

    name: 'grid-layout',

    data() {

        let val = this.modelValue || {};

        if (!val.columns) {
            val.columns = [];
        }

        return {
            val,
            active: false,
            showPreview: this.preview
        }
    },

    props: {
        modelValue: {
            type: Object,
            default: {}
        },
        group: {
            type: String,
            default: null
        },
        level: {
            type: Number,
            default: 0
        },
        preview: {
            type: Boolean,
            default: false
        },
        allowedComponents: {
            type: Array,
            default: []
        },
    },

    watch: {
        val: {
            handler() { this.update() },
            deep: true
        },
        modelValue: {
            handler(val) {
                this.val = this.modelValue || [];
                this.update();
            },
            deep: true
        },
        preview(val) {
            this.showPreview = val;
        }
    },

    computed: {
        cols() {
            return (this.val.data && this.val.data.colWidth) || 2;
        }
    },

    methods: {

        addColumn(idx = 0) {

            let column = {
                data: {},
                components: []
            };

            if (!this.val.columns.length) {
                this.val.columns.push(column);
            } else {
                this.val.columns.splice(idx + 1, 0, column);
            }

        },

        update() {
            this.$emit('update:modelValue', this.val)
        },
    },

    template: /*html*/`
        <kiss-card class="kiss-visible-toggle" @mouseenter="active=true" @mouseleave="active=false">

            <kiss-grid :cols="cols" gap="small">
                <div class="kiss-flex-1" v-for="(column, idx) in val.columns">
                    <kiss-card>
                        <div class="kiss-margin-xsmall kiss-flex kiss-flex-middle kiss-visible-toggle animated fadeIn" v-if="active">
                            <icon class="kiss-margin-xsmall-right kiss-color-muted">view_week</icon>
                            <div class="kiss-text-bold kiss-text-upper kiss-size-xsmall kiss-color-muted kiss-flex-1">{{ t('Column') }}</div>
                            <a class="kiss-size-xsmall kiss-flex kiss-color-danger kiss-margin-small-left kiss-hidden-hover" @click="val.columns.splice(val.columns.indexOf(column), 1)" :title="t('Remove column')"><icon>remove_circle</icon></a>
                            <a class="kiss-size-xsmall kiss-flex kiss-link-muted kiss-margin-xsmall-left kiss-hidden-hover" @click="addColumn(idx)" :title="t('Add column')"><icon>add_circle</icon></a>
                        </div>
                        <field-layout v-model="column.components" :group="group" :allowedComponents="allowedComponents" :level="++level" :preview="showPreview"></field-layout>
                    </kiss-card>
                </div>
            </kiss-grid>

            <div class="kiss-padding kiss-align-center kiss-color-muted" v-if="!val.columns.length">
                <button type="button" class="kiss-button kiss-button-small kiss-margin-small" @click="addColumn(0)">{{ t('Add column') }}</button>
            </div>
        </kiss-card>
    `
}
