export default {

    name: 'row-layout',

    data() {

        let val = this.modelValue || {};

        if (!val.columns) {
            val.columns = [];
        }

        return {
            val,
            active: false,
            showPreview: this.preview
        }
    },

    props: {
        modelValue: {
            type: Object,
            default: {}
        },
        group: {
            type: String,
            default: null
        },
        level: {
            type: Number,
            default: 0
        },
        preview: {
            type: Boolean,
            default: false
        },
        allowedComponents: {
            type: Array,
            default: []
        },
    },

    watch: {
        val: {
            handler() { this.update() },
            deep: true
        },
        modelValue: {
            handler(val) {
                this.val = this.modelValue || [];
                this.update();
            },
            deep: true
        },
        preview(val) {
            this.showPreview = val;
        }
    },

    methods: {

        addColumn(idx = 0) {

            if ((this.val.columns.length + 1) > 4) {
                App.ui.notify('Max four columns per row allowed', 'error');
                return;
            }

            let column = {
                data: {
                    width: null
                },
                components: []
            };

            if (!this.val.columns.length) {
                this.val.columns.push(column);
            } else {
                this.val.columns.splice(idx + 1, 0, column);
            }

        },

        update() {
            this.$emit('update:modelValue', this.val)
        },
    },

    template: /*html*/`
        <kiss-card class="kiss-visible-toggle" @mouseenter="active=true" @mouseleave="active=false">

            <kiss-row gap="small" match="true">
                <div :class="column.data.width ? 'kiss-width-'+column.data.width: 'kiss-flex-1'" v-for="(column, idx) in val.columns">
                    <kiss-card>
                        <div class=" kiss-flex kiss-flex-middle kiss-margin-xsmall kiss-visible-toggle animated fadeIn" v-if="active">

                            <div class="kiss-overlay-input">
                                <span class="kiss-text-caption kiss-flex kiss-flex-middle">{{ column.data.width || 'auto' }}</span>
                                <select v-model="column.data.width">
                                    <option :value="null">Auto</option>
                                    <option value="1-2">1-2</option>
                                    <option value="1-3">1-3</option>
                                    <option value="1-4">1-4</option>
                                    <option value="2-3">2-3</option>
                                    <option value="3-4">3-4</option>
                                </select>
                            </div>
                            <div class="kiss-flex-1"></div>
                            <a class="kiss-size-xsmall kiss-flex kiss-color-danger kiss-margin-small-left kiss-hidden-hover" @click="val.columns.splice(val.columns.indexOf(column), 1)" :title="t('Remove column')"><icon>remove_circle</icon></a>
                            <a class="kiss-size-xsmall kiss-flex kiss-link-muted kiss-margin-xsmall-left kiss-hidden-hover" @click="addColumn(idx)" :title="t('Add column')"><icon>add_circle</icon></a>
                        </div>
                        <field-layout v-model="column.components" :group="group" :allowedComponents="allowedComponents" :level="++level" :preview="showPreview"></field-layout>
                    </kiss-card>
                </div>
            </kiss-row>

            <div class="kiss-padding kiss-align-center kiss-color-muted" v-if="!val.columns.length">
                <button type="button" class="kiss-button kiss-button-small kiss-margin-small" @click="addColumn(0)">{{ t('Add column') }}</button>
            </div>
        </kiss-card>
    `
}
