<?php $this->start('app.layout.header') ?>
<?=$this->assets([
    'pages:assets/storefront/admin/storefront.css',
    ['src' => 'app:assets/js/admin.js', 'type' => 'module'],
    ['src' => 'pages:assets/storefront/admin/storefront.js', 'type' => 'module'],
], $this->retrieve('app.version'));?>
<?php $this->end('app.layout.header') ?>

<vue-view>

    <div class="storefront-container kiss-flex kiss-flex-column" style="height:100vh;padding: 20px;" :style="{opacity:init ? 1:0}">

        <div class="storefront-header kiss-flex kiss-flex-middle">
            <div class="kiss-margin-small-right">
                <img class="app-logo" src="<?=$this->helper('theme')->logo()?>" alt="Logo" style="height:30px;width:auto;">
            </div>
            <div class="kiss-flex-1">
                <span class="kiss-text-bold"><?=$this['app.name']?></span>
            </div>
            <a class="kiss-margin-large-left" :href="src">
                <kiss-svg class="kiss-color-muted" :src="$base('system:assets/icons/close.svg')" width="16"><canvas width="16" height="16"></canvas></kiss-svg>
            </a>
        </div>
        <div class="kiss-flex kiss-flex-1">
            <div class="kiss-width-1-6 kiss-margin-right">

                <app-loader v-if="!init"></app-loader>

                <div class="kiss-margin-top kiss-padding kiss-color-muted" v-if="storefront && !hasModules">
                    {{ t('No content modules found on the current page') }}
                </div>

                <div class="kiss-margin-top" v-if="hasModules">

                    <div v-if="!activeModule">

                        <div class="animated fadeInLeft">
                            <a class="kiss-display-block kiss-margin-small kiss-link-muted kiss-text-capitalize kiss-size-4" @click="activeModule = name" v-for="name in Object.keys(modules)">
                                {{ name }}
                            </a>
                        </div>
                    </div>

                    <div class="kiss-margin animated fadeInLeft fast" v-if="activeModule">
                        <a class="kiss-text-caption kiss-text-bold kiss-color-muted" @click="activeModule = null">← {{ t('Back') }}</a>
                    </div>

                    <div class="animated fadeInLeft fast" v-if="activeModule">
                        <component :is="'storefront-module-'+activeModule" v-bind="modules[activeModule]"></component>
                    </div>

                </div>

            </div>
            <div class="storefront-preview kiss-bgcolor-contrast kiss-flex kiss-flex-column kiss-flex-1">
                <kiss-card class="kiss-padding kiss-flex" theme="contrast shadowed" style="z-index:1">

                    <div class="kiss-size-small kiss-flex-1 kiss-margin-right">
                        <strong>{{title || 'No title'}}</strong>
                        <div class="kiss-size-xsmall kiss-color-muted kiss-text-truncate">{{src}}</div>
                    </div>
                    <div class="kiss-size-4 kiss-margin-small-left kiss-visible@m"><a :class="(device=='phone') ? 'kiss-link-muted':'kiss-color-muted'" @click="device='phone'"><icon class="larger">smartphone</icon></a></div>
                    <div class="kiss-size-4 kiss-margin-small-left kiss-visible@m"><a :class="(device=='computer') ? 'kiss-link-muted':'kiss-color-muted'" @click="device='computer'"><icon class="larger">desktop_windows</icon></a></div>

                </kiss-card>
                <div class="kiss-flex-1 kiss-position-relative">
                    <div class="kiss-cover">
                        <iframe :src="src" @load="updateSrc" :style="Object.assign(modes[device])" :device="device" ref="preview"></iframe>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <app-loader-cover v-if="!validated"></app-loader-cover>

    <script type="module">

        export default {

            data() {
                return {
                    init: false,
                    validated: false,
                    src: '<?=$src?>',
                    title: '',
                    locale: 'default',
                    storefront: null,
                    activeModule: null,
                    device: 'computer',
                    modes: {
                        phone: {width: '360px', height: '640px'},
                        computer: {width: '100%', height: '100%'},
                    }
                }
            },

            computed: {

                hasModules() {
                    return Object.keys(this.modules).length > 0;
                },

                modules() {

                    if (!this.storefront || !this.storefront.modules) return {};

                    let modules = {};

                    Object.keys(this.storefront.modules || {}).forEach(_module => {

                        if (!VueView.components[`storefront-module-${_module}`]) {
                            return;
                        }

                        modules[_module] = this.storefront.modules[_module];
                    });

                    return modules;
                }
            },

            mounted() {

                window.addEventListener('message', (e) => {

                    if (!e.data.event) return;

                    let event = e.data.event;
                    let data = e.data.data || {};

                    switch (event) {
                        case 'storefront:load':

                            this.src = data.src;
                            this.title = data.title;
                            this.storefront = data.storefront;
                            this.activeModule = null;
                            this.locale = this.storefront.locale || 'default';

                            this.validated = true;
                            this.init = true;
                            break;
                        case 'storefront:unload':
                            this.storefront = null;
                            this.activeModule = null;
                            this.validated = false;
                            this.locale = 'default';
                            break;
                    }

                }, false);
            },

            methods: {
                updateSrc(e) {
                    //console.log(e.target)
                },

                highlight(item) {
                    this.send('storefront:highlight', item);
                },

                send(event, data) {
                    this.$refs.preview.contentWindow.postMessage({event, data: JSON.parse(JSON.stringify(data || {}))}, '*');
                }
            }
        }

    </script>

</vue-view>
