<?php

use \GuzzleHttp\Client;

return [
    'name' => 'layout',
    'label' => 'Layout Components',
    'icon' => 'layout:assets/icons/layout.svg',
    'fields' => (function() use($app) {

        $components = $app->dataStorage->find('layout/components')->toArray();
        $options = [];

        foreach ($components as $component) {

            if (isset($component['core']) && $component['core']) continue;

            $options[] = [
                'value' => $component['name'],
                'label' => isset($component['meta']['label']) && trim($component['meta']['label']) ? $component['meta']['label'] : $component['name'],
            ];
        }

        if (!count($options)) {
            return null;
        }

        return [
            [
                'name' => 'components',
                'type' => 'select',
                'info' => 'Custom components',
                'opts' => [
                    'options' => $options,
                    'multiple' => true
                ],
            ]
        ];
    })(),

    'sync:push' => function(array $settings = [], array $target = null, Client $client = null) {

        $settings = array_merge([
            'syncAll' => true,
            'components' => []
        ], $settings);

        $components = $this->dataStorage->find('layout/components', [
            'sort' => ['name' => 1]
        ])->toArray();

        if (!$settings['syncAll']) {

            if (!count($settings['components'])) {
                return ['message' => 'no components selected'];
            }

            $components = array_filter($components, function($component) use($settings) {
                return in_array($component['name'], $settings['components']);
            });
        }

        $payload = [
            'components' => $components
        ];

        $client->request('POST', 'api/sync/job', [
            'json' => [
                'job' => 'layout',
                'mode' => 'push',
                'payload' => $this->helper('jwt')->encode($payload, $target['syncKey'])
            ]
        ]);
    },

    'on:push' => function($payload = null) {

        if (!isset($payload['components'])) {
            return ['message' => 'no components'];
        }

        foreach ($payload['components'] as $component) {

            $this->dataStorage->remove('layout/components', ['$or' => [
                ['_id' => $component['_id']],
                ['name' => $component['name']],
            ]]);

            $this->dataStorage->insert('layout/components', $component);
        }

        $this->helper('layoutComponents')->cache();

        return ['success' => true];
    },

    'sync:pull' => function(array $settings = [], array $target = null, Client $client = null) {

        $settings = array_merge([
            'syncAll' => true,
            'components' => []
        ], $settings);

        $response = $client->request('POST', 'api/sync/job', [
            'json' => [
                'job' => 'layout',
                'mode' => 'pull',
                'payload' => $this->helper('jwt')->encode(['components' => true], $target['syncKey'])
            ]
        ]);

        $payload = json_decode($response->getBody()->getContents(), true);

        if (!isset($payload['components'])) {
            return ['message' => 'no components'];
        }

        $components = $payload['components'];

        if (!$settings['syncAll']) {

            if (!count($settings['components'])) {
                return ['message' => 'no components selected'];
            }

            $components = array_filter($components, function($component) use($settings) {
                return in_array($component['name'], $settings['components']);
            });
        }

        foreach ($components as $component) {

            $this->dataStorage->remove('layout/components', ['$or' => [
                ['_id' => $component['_id']],
                ['name' => $component['name']],
            ]]);

            $this->dataStorage->insert('layout/components', $component);
        }

        $this->helper('layoutComponents')->cache();

        return true;
    },

    'on:pull' => function($payload = null) {

        $payload = [
            'components' => $this->dataStorage->find('layout/components')->toArray()
        ];

        return $payload;
    }
];
