<?php

// Register Helpers
$this->helpers['webhooks'] = 'Webhooks\\Helper\\Webhooks';

// webhooks api
$this->module('webhooks')->extend([

    // memoize data
    '_envs' => null,

    'execute' => function(array $webhook, $payload = null) {

        if (is_null($this->props['_envs'])) {
            $this->props['_envs'] = getenv();
        }

        $headers = [];
        $data    = null;
        $envs    = $this->props['_envs'];
        $envify  = function($str) use($envs) {

            foreach ($envs as $key => $value)  {
                if (!is_string($value)) continue;
                $str = str_replace("\${$key}", $value, $str);
            }

            return $str;
        };

        $url = $envify(trim($webhook['url']));
        $method = $webhook['method'] ?? 'POST';

        if ($webhook['body']['payload']) {

            if ($webhook['body']['custom']) {
                $data = $webhook['body']['contents'] ?? [];
            } elseif ($payload) {
                $data = $payload;
            }

            if ($data) {

                if ($method == 'GET') {
                    $data = http_build_query($data);
                } else {
                    $data = json_encode($data);
                }

                $data = $envify($data);
            }
        }

        // add custom headers
        if (is_array($webhook['headers'])) {

            foreach ($webhook['headers'] as $h) {

                if (!isset($h['key'], $h['val'])) continue;
                if (!$h['key'] || !$h['val']) continue;

                $headers[] = implode(': ', [$h['key'], $envify($h['val'])]);
            }
        }

        if ($data && $method == 'GET') {
            $url .= (strpos($url, '?') !== false ? '&':'?').$data;
        }

        $ch = curl_init($url);

        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
        curl_setopt($ch, CURLOPT_TIMEOUT, 1);
        curl_setopt($ch, CURLOPT_CUSTOMREQUEST, $method);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

        if ($data && $method != 'GET') {
            curl_setopt($ch, CURLOPT_POSTFIELDS, $data);
            $headers[] = 'Content-Type: application/json';
            $headers[] = 'Content-Length:'.strlen($data);
        }

        curl_setopt($ch, CURLOPT_HEADER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

        $error = null;
        $content = curl_exec($ch);

        if ($content === false) {

            $errorCode = curl_errno($ch);
            $errorMessage = curl_error($ch);

            $error = [
                'code' => $errorCode,
                'message' => $errorMessage
            ];

        } else {

            $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);

            if ($httpCode >= 400) {
                $error = [
                    'code' => $httpCode,
                    'message' => $content
                ];
            }
        }

        if ($error) {
            $this->app->module('system')->log("Webhook failed: {$webhook['name']}", channel: 'webhooks', type: 'error', context: $error);
        }

        curl_close($ch);

        return $content;
    }
]);


// load admin related code
$this->on('app.admin.init', function() {
    include(__DIR__.'/admin.php');
});

// register events defined for webhooks
$this->on(['app.api.request', 'app.admin.request'], function($request) {

    if (in_array($request->route, ['/app-event-stream', '/check-session', '/app.i18n.data.js', '/utils/csrf/login'])) {
        return;
    }

    $trigger = new ArrayObject([]);

    try {

        $webhooks = $this->helper('webhooks')->hooks();

        if (!count($webhooks)) {
            return;
        }

        foreach ($webhooks as $webhook) {

            if (!isset($webhook['events']) || !$webhook['enabled'] || !count($webhook['events'])) continue;

            $this->on($webhook['events'], function() use($webhook, $trigger) {
                $trigger[] = ['webhook' => $webhook, 'payload' => func_get_args()];
            });
        }

    } catch (Throwable $e) {
        return;
    }

    $this->on('after', function() use($trigger) {

        if (!count($trigger)) return;

        $this->helper('async')->exec('

            foreach ($trigger as $t) {
                Cockpit()->module("webhooks")->execute($t["webhook"], $t["payload"]);
            }
        ', ['trigger' => $trigger->getArrayCopy()]);
    });

}, -1000);
